@@ -1,26 +1,28 @@
 import { css } from '@emotion/css';
-import React from 'react';
 
-import { GrafanaTheme2, urlUtil } from '@grafana/data';
+import { GrafanaTheme2 } from '@grafana/data';
 import { featureEnabled, reportInteraction } from '@grafana/runtime';
 import { LinkButton, useStyles2 } from '@grafana/ui';
 import { UpgradeBox, UpgradeContentVertical } from 'app/core/components/Upgrade/UpgradeBox';
 import { highlightTrial } from 'app/features/admin/utils';
-import { ShareModalTabProps } from 'app/features/dashboard/components/ShareModal';
-import { getTimeSrv } from 'app/features/dashboard/services/TimeSrv';
-import { getVariablesUrlParams } from 'app/features/variables/getAllVariableValuesForUrl';
+import { ShareModalTabProps } from 'app/features/dashboard/components/ShareModal/types';
+import { DashboardModel } from 'app/features/dashboard/state/DashboardModel';
+import { DashboardScene } from 'app/features/dashboard-scene/scene/DashboardScene';
 
-export const CreateReportTab = ({ dashboard, onDismiss }: ShareModalTabProps) => {
+import { getNewReportUrl } from './utils/url';
+
+interface Props extends Omit<ShareModalTabProps, 'dashboard'> {
+  dashboard: DashboardModel | DashboardScene;
+}
+export const CreateReportTab = ({ dashboard, onDismiss }: Props) => {
   const styles = useStyles2(getStyles);
-  const getUrl = () => {
-    const variablesQuery = urlUtil.toUrlParams(getVariablesUrlParams());
-    const timeRangeUrl = urlUtil.toUrlParams(getTimeSrv().timeRangeForUrl());
-
-    return `?${variablesQuery}&${timeRangeUrl}&db-uid=${dashboard.uid}&db-name=${dashboard.title}`;
-  };
-
   const isReportsCreationDisabled = !featureEnabled('reports.creation');
 
+  function onClickCreateReport() {
+    reportInteraction('dashboards_sharing_report_create_clicked');
+    onDismiss && onDismiss();
+  }
+
   if (isReportsCreationDisabled) {
     return (
       <div className={styles.container}>
@@ -37,11 +39,6 @@ export const CreateReportTab = ({ dashboard, onDismiss }: ShareModalTabProps) =>
     );
   }
 
-  function onClickCreateReport() {
-    reportInteraction('dashboards_sharing_report_create_clicked');
-    onDismiss && onDismiss();
-  }
-
   return (
     <>
       {highlightTrial() && (
@@ -59,7 +56,7 @@ export const CreateReportTab = ({ dashboard, onDismiss }: ShareModalTabProps) =>
           </h6>
         </div>
       )}
-      <LinkButton href={`reports/new/${getUrl()}`} onClick={onClickCreateReport} className={styles.button}>
+      <LinkButton href={getNewReportUrl(dashboard)} onClick={onClickCreateReport} className={styles.button}>
         Create report using this dashboard
       </LinkButton>
       {highlightTrial() && (
@@ -73,20 +70,20 @@ export const CreateReportTab = ({ dashboard, onDismiss }: ShareModalTabProps) =>
 
 const getStyles = (theme: GrafanaTheme2) => {
   return {
-    container: css`
-      display: flex;
-      flex-direction: column;
-      align-items: flex-start;
-    `,
-    button: css`
-      margin-right: ${theme.spacing(2)};
-    `,
-    highlight: css`
-      margin-bottom: ${theme.spacing(3)};
+    container: css({
+      display: 'flex',
+      flexDirection: 'column',
+      alignItems: 'flex-start',
+    }),
+    button: css({
+      marginRight: theme.spacing(2),
+    }),
+    highlight: css({
+      marginBottom: theme.spacing(3),
 
-      h6 {
-        font-weight: ${theme.typography.fontWeightLight};
+      h6: {
+        fontWeight: theme.typography.fontWeightLight,
       }
-    `,
+    }),
   };
 };
