@@ -1,24 +1,27 @@
 import { css, cx } from '@emotion/css';
 import { capitalize } from 'lodash';
-import React, { useEffect } from 'react';
+import { useEffect } from 'react';
 import { useForm } from 'react-hook-form';
 import { connect, ConnectedProps } from 'react-redux';
+import { useNavigate } from 'react-router-dom-v5-compat';
 
 import { GrafanaTheme2 } from '@grafana/data';
-import { locationService, reportInteraction } from '@grafana/runtime';
+import { reportInteraction } from '@grafana/runtime';
 import { FieldSet, Icon, LinkButton, useStyles2 } from '@grafana/ui';
 import { formatUtcOffset } from '@grafana/ui/src/components/DateTimePickers/TimeZonePicker/TimeZoneOffset';
+import config from 'app/core/config';
 
 import {
   EnterpriseStoreState,
   ReportDashboard,
   ReportDataToRender,
+  ReportFormat,
   ReportState,
   SchedulingData,
   SchedulingFrequency,
   StepKey,
 } from '../../types';
-import { BASE_URL, defaultScaleFactor, reportScales } from '../constants';
+import { BASE_URL, getZoomOptions } from '../constants';
 import { createReport, updateReport } from '../state/actions';
 import { clearReportState, initialState } from '../state/reducers';
 import { getFormatted, getTimeRangeDisplay } from '../utils/dateTime';
@@ -53,19 +56,20 @@ export const Confirm = ({ report, createReport, updateReport, clearReportState,
     handleSubmit,
     formState: { isSubmitSuccessful },
   } = useForm();
+  const navigate = useNavigate();
 
   const styles = useStyles2(getStyles);
   const editMode = !!reportId && !isUpdated;
   const disableSubmit = getMissingFields(report);
 
-  const { time: startTime, date: startDate } = getFormatted(schedule.startDate);
-  const { time: endTime, date: endDate } = getFormatted(schedule.endDate);
+  const { time: startTime, date: startDate } = getFormatted(schedule.startDate, schedule.timeZone);
+  const { time: endTime, date: endDate } = getFormatted(schedule.endDate, schedule.timeZone);
 
   useEffect(() => {
     if (isSubmitSuccessful) {
-      locationService.push(BASE_URL);
+      navigate(BASE_URL);
     }
-  }, [isSubmitSuccessful]);
+  }, [isSubmitSuccessful, navigate]);
 
   const submitReport = async () => {
     const createOrUpdate = !!report.id ? updateReport : createReport;
@@ -90,6 +94,7 @@ export const Confirm = ({ report, createReport, updateReport, clearReportState,
   };
 
   const { orientation: defaultOrientation, layout: defaultLayout } = initialState.report.options;
+  const newPDFRenderingEnabled = config.featureToggles.newPDFRendering!;
   const reportData: ReportDataToRender = [
     {
       title: 'Select dashboard',
@@ -121,12 +126,32 @@ export const Confirm = ({ report, createReport, updateReport, clearReportState,
       id: StepKey.FormatReport,
       items: [
         { title: 'Preferred format*', value: getFormatsDisplay(formats), id: 'formats', required: true },
-        ...(formats.includes('pdf')
-          ? [
-              { title: 'PDF orientation', value: capitalize(options.orientation || defaultOrientation) },
-              { title: 'PDF layout', value: capitalize(options.layout || defaultLayout) },
-              { title: 'Scale factor', value: reportScales[report.scaleFactor || defaultScaleFactor].label },
-            ]
+        ...(formats.includes(ReportFormat.PDF)
+          ? newPDFRenderingEnabled
+            ? [
+                { title: 'PDF orientation', value: capitalize(options.orientation || defaultOrientation) },
+                { title: 'PDF layout', value: capitalize(options.layout || defaultLayout) },
+                {
+                  title: 'Scale factor',
+                  value:
+                    getZoomOptions(newPDFRenderingEnabled).find(
+                      (option) => option.value === report.scaleFactor && !option.isDisabled
+                    )?.label || '100%',
+                },
+                { title: 'PDF show template variables', value: options.pdfShowTemplateVariables ? 'Yes' : 'No' },
+                { title: 'Combine all PDFs in one file', value: options.pdfCombineOneFile ? 'Yes' : 'No' },
+              ]
+            : [
+                { title: 'PDF orientation', value: capitalize(options.orientation || defaultOrientation) },
+                { title: 'PDF layout', value: capitalize(options.layout || defaultLayout) },
+                {
+                  title: 'Scale factor',
+                  value:
+                    getZoomOptions(newPDFRenderingEnabled).find(
+                      (option) => option.value === report.scaleFactor && !option.isDisabled
+                    )?.label || '100%',
+                },
+              ]
           : []),
       ],
     },
@@ -174,10 +199,7 @@ export const Confirm = ({ report, createReport, updateReport, clearReportState,
         { title: 'Recipients*', value: report.recipients, id: 'recipients', required: true },
         { title: 'Reply-to-email', value: report.replyTo || 'none' },
         { title: 'Message', value: report.message || 'none' },
-        {
-          title: 'Dashboard link',
-          value: report.enableDashboardUrl ? <Icon name={'check'} size={'xl'} /> : <Icon name={'minus'} size={'xl'} />,
-        },
+        { title: 'Dashboard link', value: report.enableDashboardUrl ? 'Yes' : 'No' },
       ],
     },
   ];
@@ -238,47 +260,47 @@ export default connector(Confirm);
 
 const getStyles = (theme: GrafanaTheme2) => {
   return {
-    section: css`
-      width: 100%;
-      padding: ${theme.spacing(3, 0)};
-      margin-bottom: ${theme.spacing(3)};
-    `,
-    sectionHeader: css`
-      display: flex;
-      align-items: center;
-      justify-content: space-between;
-      padding: ${theme.spacing(1)};
-      border: 1px solid ${theme.colors.border.weak};
-    `,
-    sectionTitle: css`
-      margin: 0;
-    `,
-    row: css`
-      border: 1px solid ${theme.colors.border.weak};
-      border-top: none;
-      display: flex;
-      width: 100%;
-      padding: ${theme.spacing(1)};
-    `,
-    warning: css`
-      color: ${theme.colors.warning.text};
-    `,
-    title: css`
-      width: 30%;
-      color: ${theme.colors.text.secondary};
-    `,
-    textMuted: css`
-      color: ${theme.colors.text.secondary};
-    `,
-    value: css`
-      width: 70%;
-      word-break: break-word;
-    `,
-    dashboardLink: css`
-      color: ${theme.colors.text.primary};
-      font-size: ${theme.typography.body.fontSize};
-      margin-top: 0;
-    `,
+    section: css({
+      width: '100%',
+      padding: theme.spacing(3, 0),
+      marginBottom: theme.spacing(3),
+    }),
+    sectionHeader: css({
+      display: 'flex',
+      alignItems: 'center',
+      justifyContent: 'space-between',
+      padding: theme.spacing(1),
+      border: `1px solid ${theme.colors.border.weak}`,
+    }),
+    sectionTitle: css({
+      margin: 0,
+    }),
+    row: css({
+      border: `1px solid ${theme.colors.border.weak}`,
+      borderTop: 'none',
+      display: 'flex',
+      width: '100%',
+      padding: theme.spacing(1),
+    }),
+    warning: css({
+      color: theme.colors.warning.text,
+    }),
+    title: css({
+      width: '30%',
+      color: theme.colors.text.secondary,
+    }),
+    textMuted: css({
+      color: theme.colors.text.secondary,
+    }),
+    value: css({
+      width: '70%',
+      wordBreak: 'break-word',
+    }),
+    dashboardLink: css({
+      color: theme.colors.text.primary,
+      fontSize: theme.typography.body.fontSize,
+      marginTop: 0,
+    }),
   };
 };
 
@@ -297,7 +319,7 @@ const VariablesPreview = ({ variables, className }: VariablesPreviewProps) => {
     <>
       {Object.entries(variables).map(([key, value]) => (
         <span key={key}>
-          <span className={className}>{key}</span>: {value};{' '}
+          <span className={className}>{key}</span>: {value.join(', ')};{' '}
         </span>
       ))}
     </>
